@@ -5,6 +5,7 @@ import re
 import yaml
 from qualys_etl.etld_lib import etld_lib_functions as etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_date_time_functions as api_date
+from qualys_etl.etld_lib import etld_lib_sqlite_tables as etld_lib_sqlite_tables
 
 global setup_completed_flag           # Set to true when completed
 # APPLICATION
@@ -396,6 +397,7 @@ def get_host_list_user_config():
     global host_list_payload_option
     global qetl_manage_user_selected_datetime
     global host_list_csv_truncate_cell_limit
+    global host_list_sqlite_file
 
     host_list_export_dir = etld_lib_config_settings_yaml_dict.get('host_list_export_dir')
     host_list_data_dir = qetl_user_data_dir
@@ -418,9 +420,18 @@ def get_host_list_user_config():
         etld_lib_functions.logger.info(f"host_list_vm_processed_after set by qetl_manage_user -d option - "
                              f"{host_list_vm_processed_after}")
     elif host_list_vm_processed_after == 'default':
-        #  By default get last 1 days of changes.
-        host_list_vm_processed_after = api_date.get_utc_date_minus_days(1)
-        etld_lib_functions.logger.info(f"host_list_vm_processed_after utc.now minus 7 days - {host_list_vm_processed_after}")
+        #  By default get last 1 days of changes or if host_list_sqlite.db file exists
+        #  use max_date to execute from that date.
+        (min_date, max_date) = etld_lib_sqlite_tables.get_q_table_min_max_dates(
+            host_list_sqlite_file, "LAST_VULN_SCAN_DATETIME", "Q_Host_List")
+        if max_date.startswith("20"):
+            etld_lib_functions.logger.info(f"Found Q_Host_List Min Date: {min_date} Max Date: {max_date}")
+            max_date = re.sub(":..Z$", ":00Z", max_date)
+            host_list_vm_processed_after = max_date
+            etld_lib_functions.logger.info(f"host_list_vm_processed_after using max_date from database - {host_list_vm_processed_after}")
+        else:
+            host_list_vm_processed_after = api_date.get_utc_date_minus_days(1)
+            etld_lib_functions.logger.info(f"host_list_vm_processed_after using utc.now minus 1 days - {host_list_vm_processed_after}")
     else:
         etld_lib_functions.logger.info(f"host_list_vm_processed_after yaml - {host_list_vm_processed_after}")
 
